@@ -662,7 +662,7 @@ class IrcBot(object):
                 "type": "part",
                 "nick": g[1],
                 "channel": g[2],
-                "message": g[3],
+                "text": g[3],
             },
             r"^:(.+) 433 (\S*) (\S*) :(.*)\s*$": lambda g: {
                 "type": "nickinuse",
